API Reference
=============

.. automodapi:: btrack

.. automodapi:: btrack.btypes

.. automodapi:: btrack.models

.. automodapi:: btrack.io

.. automodapi:: btrack.utils
   :allowed-package-names: btrack._localization, btrack.utils
